pub struct CollectionMetadataTimeline {
pub collection_metadata: CollectionMetadata,
pub timeline_times: Vec<UintRange>,
}Fields
collection_metadata: CollectionMetadatatimeline_times: Vec<UintRange>Trait Implementations
Sourceimpl Clone for CollectionMetadataTimeline
impl Clone for CollectionMetadataTimeline
Sourcefn clone(&self) -> CollectionMetadataTimeline
fn clone(&self) -> CollectionMetadataTimeline
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CollectionMetadataTimeline
impl Debug for CollectionMetadataTimeline
Sourceimpl<'de> Deserialize<'de> for CollectionMetadataTimeline
impl<'de> Deserialize<'de> for CollectionMetadataTimeline
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CollectionMetadataTimeline
impl JsonSchema for CollectionMetadataTimeline
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreimpl StructuralPartialEq for CollectionMetadataTimeline