pub struct CustomDataTimeline {
pub custom_data: String,
pub timeline_times: Vec<UintRange>,
}Fields
custom_data: Stringtimeline_times: Vec<UintRange>Trait Implementations
Sourceimpl Clone for CustomDataTimeline
impl Clone for CustomDataTimeline
Sourcefn clone(&self) -> CustomDataTimeline
fn clone(&self) -> CustomDataTimeline
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CustomDataTimeline
impl Debug for CustomDataTimeline
Sourceimpl<'de> Deserialize<'de> for CustomDataTimeline
impl<'de> Deserialize<'de> for CustomDataTimeline
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CustomDataTimeline
impl JsonSchema for CustomDataTimeline
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CustomDataTimeline
impl PartialEq for CustomDataTimeline
Sourceimpl Serialize for CustomDataTimeline
impl Serialize for CustomDataTimeline
impl StructuralPartialEq for CustomDataTimeline