pub struct OffChainBalancesMetadataTimeline {
pub off_chain_balances_metadata: OffChainBalancesMetadata,
pub timeline_times: Vec<UintRange>,
}Fields
off_chain_balances_metadata: OffChainBalancesMetadatatimeline_times: Vec<UintRange>Trait Implementations
Sourceimpl Clone for OffChainBalancesMetadataTimeline
impl Clone for OffChainBalancesMetadataTimeline
Sourcefn clone(&self) -> OffChainBalancesMetadataTimeline
fn clone(&self) -> OffChainBalancesMetadataTimeline
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for OffChainBalancesMetadataTimeline
impl<'de> Deserialize<'de> for OffChainBalancesMetadataTimeline
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for OffChainBalancesMetadataTimeline
impl JsonSchema for OffChainBalancesMetadataTimeline
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OffChainBalancesMetadataTimeline
impl PartialEq for OffChainBalancesMetadataTimeline
Sourcefn eq(&self, other: &OffChainBalancesMetadataTimeline) -> bool
fn eq(&self, other: &OffChainBalancesMetadataTimeline) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OffChainBalancesMetadataTimeline