pub struct QueryGetProtocolResponse {
pub protocol: Protocol,
}Fields
protocol: ProtocolTrait Implementations
Sourceimpl Clone for QueryGetProtocolResponse
impl Clone for QueryGetProtocolResponse
Sourcefn clone(&self) -> QueryGetProtocolResponse
fn clone(&self) -> QueryGetProtocolResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryGetProtocolResponse
impl Debug for QueryGetProtocolResponse
Sourceimpl<'de> Deserialize<'de> for QueryGetProtocolResponse
impl<'de> Deserialize<'de> for QueryGetProtocolResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QueryGetProtocolResponse
impl JsonSchema for QueryGetProtocolResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QueryGetProtocolResponse
impl PartialEq for QueryGetProtocolResponse
Sourceimpl Serialize for QueryGetProtocolResponse
impl Serialize for QueryGetProtocolResponse
impl StructuralPartialEq for QueryGetProtocolResponse