pub struct QueryValueAtLocationResponse {
pub anchor_data: AnchorData,
}Fields
anchor_data: AnchorDataTrait Implementations
Sourceimpl Clone for QueryValueAtLocationResponse
impl Clone for QueryValueAtLocationResponse
Sourcefn clone(&self) -> QueryValueAtLocationResponse
fn clone(&self) -> QueryValueAtLocationResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for QueryValueAtLocationResponse
impl Debug for QueryValueAtLocationResponse
Sourceimpl<'de> Deserialize<'de> for QueryValueAtLocationResponse
impl<'de> Deserialize<'de> for QueryValueAtLocationResponse
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for QueryValueAtLocationResponse
impl JsonSchema for QueryValueAtLocationResponse
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for QueryValueAtLocationResponse
impl PartialEq for QueryValueAtLocationResponse
Sourcefn eq(&self, other: &QueryValueAtLocationResponse) -> bool
fn eq(&self, other: &QueryValueAtLocationResponse) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for QueryValueAtLocationResponse