pub struct UserBalanceStore {
pub balances: Vec<Balance>,
pub outgoing_approvals: Vec<UserOutgoingApproval>,
pub incoming_approvals: Vec<UserIncomingApproval>,
pub auto_approve_self_initiated_outgoing_transfers: bool,
pub auto_approve_self_initiated_incoming_transfers: bool,
pub user_permissions: UserPermissions,
}Fields
balances: Vec<Balance>outgoing_approvals: Vec<UserOutgoingApproval>incoming_approvals: Vec<UserIncomingApproval>auto_approve_self_initiated_outgoing_transfers: boolauto_approve_self_initiated_incoming_transfers: booluser_permissions: UserPermissionsTrait Implementations
Sourceimpl Clone for UserBalanceStore
impl Clone for UserBalanceStore
Sourcefn clone(&self) -> UserBalanceStore
fn clone(&self) -> UserBalanceStore
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for UserBalanceStore
impl Debug for UserBalanceStore
Sourceimpl<'de> Deserialize<'de> for UserBalanceStore
impl<'de> Deserialize<'de> for UserBalanceStore
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for UserBalanceStore
impl JsonSchema for UserBalanceStore
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for UserBalanceStore
impl PartialEq for UserBalanceStore
Sourceimpl Serialize for UserBalanceStore
impl Serialize for UserBalanceStore
impl StructuralPartialEq for UserBalanceStore